# siho-dict-api

![PyPI](https://img.shields.io/pypi/v/sihodictapi?style=flat-square)
![PyPI - License](https://img.shields.io/pypi/l/sihodictapi?color=information&style=flat-square)

> 一些在线词典/翻译API

仅对API进行收集和密钥逆向破解，不修改返回结果

## 安装

```
pip install sihodictapi
```